@@ -1,9 +1,6 @@
-# @(#)$Ident: Storage.pm 2013-12-31 18:24 pjf ;
-
 package File::Gettext::Storage;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.22.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 use File::Basename             qw( basename );
@@ -15,12 +12,13 @@ use Try::Tiny;
 use Unexpected::Functions      qw( NothingUpdated Unspecified );
 
 has 'gettext' => is => 'lazy', isa => Object, builder => sub {
-   File::Gettext->new( builder   => $_[ 0 ]->schema,
-                       localedir => $_[ 0 ]->localedir );
+   File::Gettext->new( builder     => $_[ 0 ]->schema,
+                       cache_class => $_[ 0 ]->cache_class,
+                       localedir   => $_[ 0 ]->localedir );
 };
 
 has 'schema'  => is => 'ro',   isa => Object,  required => TRUE,
-   handles    => [ qw( cache lang localedir ) ], weak_ref => TRUE;
+   handles    => [ qw( cache cache_class lang localedir ) ], weak_ref => TRUE;
 
 has 'storage' => is => 'ro',   isa => Object,  required => TRUE,
    handles    => [ qw( extn meta_pack meta_unpack
@@ -192,7 +190,7 @@ sub _get_key_and_newest {
 sub _gettext {
    my ($self, $path) = @_; my $gettext = $self->gettext;
 
-   $path or throw class => Unspecified, args => [ 'Path name' ];
+   $path or throw class => Unspecified, args => [ 'path name' ];
 
    my $extn = $self->_extn( $path );
 
@@ -240,10 +238,6 @@ __END__
 
 File::Gettext::Storage - Split/merge language dependent data
 
-=head1 Version
-
-This document describes v0.22.$Rev: 1 $ of L<File::Gettext::Storage>
-
 =head1 Synopsis
 
 =head1 Description
